AccountAny

Enum AccountAny 

pub enum AccountAny {
    Margin(MarginAccount),
    Cash(CashAccount),
    Betting(BettingAccount),
    Wallet(WalletAccount),
}

Variants

Implementations

Source

impl AccountAny

pub fn clone_without_events(&self) -> Self

Returns a copy without stored account state events.

pub fn id(&self) -> AccountId

pub fn last_event(&self) -> Option<AccountState>

pub fn events(&self) -> Vec<AccountState>

pub fn apply(&mut self, event: AccountState) -> Result<()>

Applies an account state event to update the account.

Errors

Returns an error if the event belongs to a different account or the account state cannot be applied (e.g., negative balance when borrowing is not allowed for a cash account).

pub fn set_calculate_account_state(&mut self, calculate_account_state: bool)

Sets whether account state should be recalculated from order fills.

pub fn balances(&self) -> IndexMap<Currency, AccountBalance>

pub fn balances_locked(&self) -> IndexMap<Currency, Money>

pub fn base_currency(&self) -> Option<Currency>

pub fn from_events(events: &[AccountState]) -> Result<Self>

Errors

Returns an error if events is empty or an account state cannot be created or applied.

pub fn calculate_pnls( &self, instrument: &InstrumentAny, fill: &OrderFilled, position: Option<Position>, ) -> Result<Vec<Money>>

Errors

Returns an error if calculating P&Ls fails for the underlying account.

pub fn calculate_commission( &self, instrument: &InstrumentAny, last_qty: Quantity, last_px: Price, liquidity_side: LiquiditySide, use_quote_for_inverse: Option<bool>, ) -> Result<Money>

Errors

Returns an error if calculating commission fails for the underlying account.

pub fn balance(&self, currency: Option<Currency>) -> Option<&AccountBalance>

Source

impl AccountAny

pub fn try_from_state(event: AccountState) -> Result<Self, &'static str>

Creates an AccountAny from an AccountState.

Errors

Returns an error if a wallet account state is invalid.